==> icradius-0.13.tar.gz: icradius-0.13/scripts/userimport.pl <==
#!/usr/bin/perl -T
########################################################################
#                                                                      #
#    userimport.pl                InnerCite                            #
#                                 Mike Machado <mike@innercite.com>    #
#                                 27 April 1999                        #
#                                                                      #
#    Imports standard RADIUS users file into mysql                     #
#                                                                      #
#                   Copyright under same terms as Cistron RADIUS       #
#                                                                      #
########################################################################


use DBI;
use strict;
my $file = shift || '';

if ($file eq '') {
  print "Usage: userimport.pl users\n";
  exit;
}

my $dbusername = 'root';
my $dbpassword = 'rootpass';
my $dbh = DBI->connect("DBI:mysql:radius", $dbusername, $dbpassword) || die "Cound not connect to radius database as $dbusername\n";

my $lastrow = 0;


open(USER, $file) || die "Cannot open $file for read\n";

my $put_default = 0;

my $sth;

my $sql = '';
my ($username, $buffer);
my $lineno = 0;
while (<USER>) {
  $lineno++;
  chop();

  next if /^#/;

  if (/^\s/) {
     $lastrow = 0;
     $_ = substr($_, 1, length($_));
     if (substr($_, length($_) -1, 1) eq ',') {
       chop();
     }
     my @avreply = split(/=/);
     $avreply[0] =~ s/^\s+//;
     $avreply[0] =~ s/\s+$//;
     $avreply[1] =~ s/^\s+//;
     $avreply[1] =~ s/\s+$//;
     $avreply[1] =~ s/,$//;
      if (substr($avreply[1], 0, 1) eq '"') {
        chop($avreply[1]);
        $avreply[1] = substr($avreply[1], 1, length($avreply[1]));
      }
      if ($put_default)
	{

       	$sth = $dbh->do("INSERT INTO usergroup VALUES \(\'\',\'$username\',\'DEFAULT\'\)");
	$sth = $dbh->do("INSERT INTO radcheck VALUES \(\'\',\'$username\',\'Auth-Type\', \'System\'\)");

	$put_default = 0;

	}
     $sth = $dbh->do("INSERT INTO radreply VALUES \(\'\',\'$username\',\'$avreply[0]\',\'$avreply[1]\'\)");

  } else {


      next if $_ eq '';
     $lastrow = 1 if $_ eq '';
     ($username, $buffer) = split(/\t|\s/,$_,2);

     $put_default = 1;


     my @check = split(/\,/, $buffer);
     foreach (@check) {
       my @avpair = split(/=/);
       $avpair[0] =~ s/^\s+//;
       $avpair[0] =~ s/\s+$//;
       $avpair[1] =~ s/^\s+//;
       $avpair[1] =~ s/\s+$//;
       $avpair[1] =~ s/,$//;
       if (substr($avpair[1], 0, 1) eq '"') {
	 # Remove quotes
         chop($avpair[1]);
         $avpair[1] = substr($avpair[1], 1, length($avpair[1]));
       }

       $sth = $dbh->do("INSERT INTO radcheck VALUES \(\'\',\'$username\',\'$avpair[0]\',\'$avpair[1]\'\)");
     }

  }


}

$dbh->disconnect;

==> icradius-0.18.tar.gz: icradius-0.18/scripts/userimport.pl <==
#!/usr/bin/perl -T
########################################################################
#                                                                      #
#    userimport.pl                InnerCite                            #
#                                 Mike Machado <mike@innercite.com>    #
#                                 27 April 1999                        #
#                                                                      #
#    Imports standard RADIUS users file into mysql                     #
#                                                                      #
#                   Copyright under same terms as Cistron RADIUS       #
#                                                                      #
########################################################################


use DBI;
use strict;
my $file = shift || '';

if ($file eq '') {
  print "Usage: userimport.pl users\n";
  exit;
}

my $dbusername = 'radius';
my $dbpassword = 'radiuspasswd';
my $dbh = DBI->connect("DBI:mysql:radius", $dbusername, $dbpassword) || die "Cound not connect to radius database as $dbusername\n";

my $lastrow = 0;


open(USER, $file) || die "Cannot open $file for read\n";

my $put_default = 0;

my $sth;

my $sql = '';
my ($username, $buffer);
my $lineno = 0;
while (<USER>) {
  $lineno++;
  chop();

  next if /^#/;

  if (/^\s/) {
     $lastrow = 0;
     $_ = substr($_, 1, length($_));
     if (substr($_, length($_) -1, 1) eq ',') {
       chop();
     }
     my @avreply = split(/=/);
     $avreply[0] =~ s/^\s+//;
     $avreply[0] =~ s/\s+$//;
     $avreply[1] =~ s/^\s+//;
     $avreply[1] =~ s/\s+$//;
     $avreply[1] =~ s/,$//;

     if (length($avreply[2]))
      { $avreply[1].="=".$avreply[2];
      }
           
      if (substr($avreply[1], 0, 1) eq '"') 
       { $avreply[1]=~ s/"//g;
       }
       
      if ($put_default)
	{

       	$sth = $dbh->do("INSERT INTO usergroup VALUES \(\'\',\'$username\',\'DEFAULT\'\)");
	$sth = $dbh->do("INSERT INTO radcheck VALUES \(\'\',\'$username\',\'Auth-Type\', \'Local\'\)");

	$put_default = 0;

	}
     $sth = $dbh->do("INSERT INTO radreply VALUES \(\'\',\'$username\',\'$avreply[0]\',\'$avreply[1]\'\)");

  } else {


      next if $_ eq '';
     $lastrow = 1 if $_ eq '';
     ($username, $buffer) = split(/\t|\s/,$_,2);

     $put_default = 1;


     my @check = split(/\,/, $buffer);
     foreach (@check) {
       my @avpair = split(/=/);
       $avpair[0] =~ s/^\s+//;
       $avpair[0] =~ s/\s+$//;
       $avpair[1] =~ s/^\s+//;
       $avpair[1] =~ s/\s+$//;
       $avpair[1] =~ s/,$//;
       
       if (length($avpair[2]))
        { $avpair[1].="=".$avpair[2];
        }

       if (substr($avpair[1], 0, 1) eq '"') {
	 # Remove quotes
	 $avpair[1]=~ s/"//g;
       }

       $sth = $dbh->do("INSERT INTO radcheck VALUES \(\'\',\'$username\',\'$avpair[0]\',\'$avpair[1]\'\)");
     }

  }


}

$dbh->disconnect;
